---

name: Submit Question
about: Ask a general question about Pyxel
title: "QST:"
labels: "Usage Question, Needs Triage"

---

- [ ] I have asked my usage related question on [Pyxel's Google Group](https://groups.google.com/forum/#!forum/pyxel-detector-framework).

---

#### Question about Pyxel

**Note**: If you'd still like to submit a question, please read [this guide](
https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports) detailing how to provide the necessary information for us to reproduce your question.

```python
# Your code here, if applicable

```